@@ -9,13 +9,11 @@ import stdnum.exceptions
 from trytond.pool import PoolMeta, Pool
 from trytond.model import fields
 from trytond.transaction import Transaction
-from trytond import backend
 
 __all__ = ['Party', 'PartyIdentifier']
 
 
-class Party:
-    __metaclass__ = PoolMeta
+class Party(metaclass=PoolMeta):
     __name__ = 'party.party'
     sepa_creditor_identifier_used = fields.Function(fields.Char(
             'SEPA Creditor Identifier Used'),
@@ -27,11 +25,10 @@ class Party:
     def __register__(cls, module_name):
         Identifier = Pool().get('party.identifier')
         cursor = Transaction().connection.cursor()
-        TableHandler = backend.get('TableHandler')
         sql_table = cls.__table__()
         identifier = Identifier.__table__()
         super(Party, cls).__register__(module_name)
-        table = TableHandler(cls, module_name)
+        table = cls.__table_handler__(module_name)
 
         # Migration from 4.0: Move sepa_creditor_identifier to identifier
         if table.column_exist('sepa_creditor_identifier'):
@@ -52,8 +49,7 @@ class Party:
                 return identifier.code
 
 
-class PartyIdentifier:
-    __metaclass__ = PoolMeta
+class PartyIdentifier(metaclass=PoolMeta):
     __name__ = 'party.identifier'
 
     @classmethod
